const datasetUrl =
  'https://gist.githubusercontent.com/SirishaManthena/143d8a4e801946f7437aec508d8f5254/raw/c138d08f102c2b8c7d61957ef9dba2d25e37cf42/nutritionalinfo.csv';

// Load dataset and create bar chart
d3.csv(datasetUrl).then((data) => {
  // Filter data to include only specified menu items
  const menuItems = [
    'Egg McMuffin',
    'Big Mac',
    'Hamburger',
    'Cheeseburger',
    'Double Cheeseburger',
    'McChicken',
    'Chicken McNuggets (10 piece)',
    'Filet-O-Fish',
    'Large French Fries',
    'Hot Fudge Sundae',
  ];
  const filteredData = data.filter((d) =>
    menuItems.includes(d.Item),
  );

  // Sort filtered data by calorie count (descending order)
  filteredData.sort(
    (a, b) => parseInt(b.Calories) - parseInt(a.Calories),
  );

  // Set up SVG dimensions and margins
  const svgWidth = 1000; // Increased SVG width
  const svgHeight = 500;
  const margin = {
    top: 50,
    right: 200,
    bottom: 70,
    left: 200, // Increased left margin
  };
  const width = svgWidth - margin.left - margin.right;
  const height = svgHeight - margin.top - margin.bottom;

  // Create SVG element
  const svg = d3
    .select('svg')
    .attr('width', svgWidth)
    .attr('height', svgHeight);

  // Create scales
  const xScale = d3
    .scaleLinear()
    .domain([
      0,
      d3.max(filteredData, (d) => parseInt(d.Calories)),
    ])
    .range([0, width]);

  const yScale = d3
    .scaleBand()
    .domain(filteredData.map((d) => d.Item))
    .range([0, height])
    .padding(0.1);

  // Create bars
  svg
    .selectAll('.bar')
    .data(filteredData)
    .enter()
    .append('rect')
    .attr('class', 'bar')
    .attr('x', margin.left)
    .attr('y', (d) => yScale(d.Item) + margin.top)
    .attr('width', (d) => xScale(parseInt(d.Calories)))
    .attr('height', yScale.bandwidth())
    .attr('fill', 'steelblue');

  // Add text labels
  svg
    .selectAll('.label')
    .data(filteredData)
    .enter()
    .append('text')
    .attr('class', 'label')
    .attr(
      'x',
      (d) =>
        margin.left + xScale(parseInt(d.Calories)) + 10,
    )
    .attr(
      'y',
      (d) =>
        yScale(d.Item) +
        margin.top +
        yScale.bandwidth() / 2,
    )
    .attr('dy', '0.35em')
    .text((d) => d.Calories + ' Calories')
    .attr('fill', 'white')
    .style('font-family', 'Arial, sans-serif')
    .style('font-size', '14px');

  // Create x-axis
  svg
    .append('g')
    .attr('class', 'x-axis')
    .attr(
      'transform',
      `translate(${margin.left}, ${height + margin.top})`,
    )
    .call(d3.axisBottom(xScale))
    .selectAll('text')
    .style('font-family', 'Arial, sans-serif')
    .style('font-size', '12px')
    .attr('transform', 'rotate(-45)')
    .style('text-anchor', 'end');

  // Create y-axis
  svg
    .append('g')
    .attr('class', 'y-axis')
    .attr(
      'transform',
      `translate(${margin.left}, ${margin.top})`,
    )
    .call(d3.axisLeft(yScale))
    .selectAll('text')
    .style('font-family', 'Arial, sans-serif')
    .style('font-size', '12px')
    .attr('transform', 'translate(-15, 0)');

  // Add x-axis label
  svg
    .append('text')
    .attr('class', 'x-axis-label')
    .attr('x', width / 2 + margin.left)
    .attr('y', height + margin.top + 50)
    .style('text-anchor', 'middle')
    .style('font-family', 'Arial, sans-serif')
    .style('font-size', '16px')
    .text('Calories');

  // Add chart title
  svg
    .append('text')
    .attr('class', 'chart-title')
    .attr('x', width / 2 + margin.left)
    .attr('y', margin.top / 2)
    .style('text-anchor', 'middle')
    .style('font-family', 'Arial, sans-serif')
    .style('font-size', '20px')
    .text(
      "Calories present in Most Popular Items of McDonald's",
    );
});
